@@ -1,4 +1,4 @@
-from mainflow.window_ui import register
+from window_ui import register
 
 
 def start_up_window():
